appconf
=======

**WARNING: CURRENTLY ALPHA AS FUCK**

Very simple tool to help manage services running on nginx. The implementation
is dead simple and is focused on my uses cases. The app will evolve with time
as new use cases arise.

